@@ -1,5 +1,5 @@
 // -------------------------------------------------------------------
-// Copyright (c) 2013-2017, AIT Austrian Institute of Technology GmbH.
+// Copyright (c) 2013-2022, AIT Austrian Institute of Technology GmbH.
 // All rights reserved. See file FMIPP_LICENSE for details.
 // -------------------------------------------------------------------
 
@@ -16,18 +16,15 @@
 
 #include "import/utility/include/InterpolatingFixedStepSizeFMU.h"
 
-
-
 using namespace std;
 
-
-InterpolatingFixedStepSizeFMU::InterpolatingFixedStepSizeFMU( const string& fmuDirUri,
-		const string& modelIdentifier,
-		const fmiBoolean loggingOn,
-		const fmiReal timeDiffResolution ) :
-	currentCommunicationPoint_( numeric_limits<fmiTime>::quiet_NaN() ),
-	finalCommunicationPoint_( numeric_limits<fmiTime>::quiet_NaN() ),
-	communicationStepSize_( numeric_limits<fmiTime>::quiet_NaN() ),	fmu_( 0 ),
+InterpolatingFixedStepSizeFMU::InterpolatingFixedStepSizeFMU( const fmippString& fmuDirUri,
+		const fmippString& modelIdentifier,
+		const fmippBoolean loggingOn,
+		const fmippReal timeDiffResolution ) :
+	currentCommunicationPoint_( numeric_limits<fmippTime>::quiet_NaN() ),
+	finalCommunicationPoint_( numeric_limits<fmippTime>::quiet_NaN() ),
+	communicationStepSize_( numeric_limits<fmippTime>::quiet_NaN() ),	fmu_( 0 ),
 	realInputRefs_( 0 ), integerInputRefs_( 0 ), booleanInputRefs_( 0 ), stringInputRefs_( 0 ),
 	nRealInputs_( 0 ), nIntegerInputs_( 0 ), nBooleanInputs_( 0 ), nStringInputs_( 0 ),
 	realOutputRefs_( 0 ), integerOutputRefs_( 0 ), booleanOutputRefs_( 0 ), stringOutputRefs_( 0 ),
@@ -53,7 +50,6 @@ InterpolatingFixedStepSizeFMU::InterpolatingFixedStepSizeFMU( const string& fmuD
 	}
 }
 
-
 InterpolatingFixedStepSizeFMU::~InterpolatingFixedStepSizeFMU()
 {
 	if ( 0 != fmu_ ) delete fmu_;
@@ -69,17 +65,16 @@ InterpolatingFixedStepSizeFMU::~InterpolatingFixedStepSizeFMU()
 	if ( stringOutputRefs_ ) delete stringOutputRefs_;
 }
 
-
-void InterpolatingFixedStepSizeFMU::defineRealInputs( const string inputs[], const size_t nInputs )
+void InterpolatingFixedStepSizeFMU::defineRealInputs( const fmippString inputs[], const fmippSize nInputs )
 {
 	if ( 0 != realInputRefs_ ) delete realInputRefs_;
 
 	nRealInputs_ = nInputs;
 	realInputRefs_ = new fmiValueReference[nInputs];
-	for ( size_t i = 0; i < nInputs; ++i ) {
+	for ( fmippSize i = 0; i < nInputs; ++i ) {
 		realInputRefs_[i] = fmu_->getValueRef( inputs[i] );
 
-		if ( fmiTrue == loggingOn_ )
+		if ( fmippTrue == loggingOn_ )
 		{
 			stringstream msg;
 			msg << "add " << inputs[i] << " (" << realInputRefs_[i] << ") "
@@ -89,17 +84,16 @@ void InterpolatingFixedStepSizeFMU::defineRealInputs( const string inputs[], con
 	}
 }
 
-
-void InterpolatingFixedStepSizeFMU::defineIntegerInputs( const string inputs[], const size_t nInputs )
+void InterpolatingFixedStepSizeFMU::defineIntegerInputs( const fmippString inputs[], const fmippSize nInputs )
 {
 	if ( 0 != integerInputRefs_ ) delete integerInputRefs_;
 
 	nIntegerInputs_ = nInputs;
 	integerInputRefs_ = new fmiValueReference[nInputs];
-	for ( size_t i = 0; i < nInputs; ++i ) {
+	for ( fmippSize i = 0; i < nInputs; ++i ) {
 		integerInputRefs_[i] = fmu_->getValueRef( inputs[i] );
 
-		if ( fmiTrue == loggingOn_ )
+		if ( fmippTrue == loggingOn_ )
 		{
 			stringstream msg;
 			msg << "add " << inputs[i] << " (" << integerInputRefs_[i] << ") "
@@ -109,17 +103,16 @@ void InterpolatingFixedStepSizeFMU::defineIntegerInputs( const string inputs[],
 	}
 }
 
-
-void InterpolatingFixedStepSizeFMU::defineBooleanInputs( const string inputs[], const size_t nInputs )
+void InterpolatingFixedStepSizeFMU::defineBooleanInputs( const fmippString inputs[], const fmippSize nInputs )
 {
 	if ( 0 != booleanInputRefs_ ) delete booleanInputRefs_;
 
 	nBooleanInputs_ = nInputs;
 	booleanInputRefs_ = new fmiValueReference[nInputs];
-	for ( size_t i = 0; i < nInputs; ++i ) {
+	for ( fmippSize i = 0; i < nInputs; ++i ) {
 		booleanInputRefs_[i] = fmu_->getValueRef( inputs[i] );
 
-		if ( fmiTrue == loggingOn_ )
+		if ( fmippTrue == loggingOn_ )
 		{
 			stringstream msg;
 			msg << "add " << inputs[i] << " (" << booleanInputRefs_[i] << ") "
@@ -129,37 +122,35 @@ void InterpolatingFixedStepSizeFMU::defineBooleanInputs( const string inputs[],
 	}
 }
 
-
-void InterpolatingFixedStepSizeFMU::defineStringInputs( const string inputs[], const size_t nInputs )
+void InterpolatingFixedStepSizeFMU::defineStringInputs( const fmippString inputs[], const fmippSize nInputs )
 {
 	if ( 0 != stringInputRefs_ ) delete stringInputRefs_;
 
 	nStringInputs_ = nInputs;
 	stringInputRefs_ = new fmiValueReference[nInputs];
-	for ( size_t i = 0; i < nInputs; ++i ) {
+	for ( fmippSize i = 0; i < nInputs; ++i ) {
 		stringInputRefs_[i] = fmu_->getValueRef( inputs[i] );
 
-		if ( fmiTrue == loggingOn_ )
+		if ( fmippTrue == loggingOn_ )
 		{
 			stringstream msg;
 			msg << "add " << inputs[i] << " (" << stringInputRefs_[i] << ") "
-			    << "to string input variables";
+			    << "to fmippString input variables";
 			fmu_->sendDebugMessage( msg.str() );
 		}
 	}
 }
 
-
-void InterpolatingFixedStepSizeFMU::defineRealOutputs( const string outputs[], const size_t nOutputs )
+void InterpolatingFixedStepSizeFMU::defineRealOutputs( const fmippString outputs[], const fmippSize nOutputs )
 {
 	if ( 0 != realOutputRefs_ ) delete realOutputRefs_;
 
 	nRealOutputs_ = nOutputs;
 	realOutputRefs_ = new fmiValueReference[nOutputs];
-	for ( size_t i = 0; i < nOutputs; ++i ) {
+	for ( fmippSize i = 0; i < nOutputs; ++i ) {
 		realOutputRefs_[i] = fmu_->getValueRef( outputs[i] );
 
-		if ( fmiTrue == loggingOn_ )
+		if ( fmippTrue == loggingOn_ )
 		{
 			stringstream msg;
 			msg << "add " << outputs[i] << " (" << realOutputRefs_[i] << ") "
@@ -169,17 +160,16 @@ void InterpolatingFixedStepSizeFMU::defineRealOutputs( const string outputs[], c
 	}
 }
 
-
-void InterpolatingFixedStepSizeFMU::defineIntegerOutputs( const string outputs[], const size_t nOutputs )
+void InterpolatingFixedStepSizeFMU::defineIntegerOutputs( const fmippString outputs[], const fmippSize nOutputs )
 {
 	if ( 0 != integerOutputRefs_ ) delete integerOutputRefs_;
 
 	nIntegerOutputs_ = nOutputs;
 	integerOutputRefs_ = new fmiValueReference[nOutputs];
-	for ( size_t i = 0; i < nOutputs; ++i ) {
+	for ( fmippSize i = 0; i < nOutputs; ++i ) {
 		integerOutputRefs_[i] = fmu_->getValueRef( outputs[i] );
 
-		if ( fmiTrue == loggingOn_ )
+		if ( fmippTrue == loggingOn_ )
 		{
 			stringstream msg;
 			msg << "add " << outputs[i] << " (" << integerOutputRefs_[i] << ") "
@@ -189,17 +179,16 @@ void InterpolatingFixedStepSizeFMU::defineIntegerOutputs( const string outputs[]
 	}
 }
 
-
-void InterpolatingFixedStepSizeFMU::defineBooleanOutputs( const string outputs[], const size_t nOutputs )
+void InterpolatingFixedStepSizeFMU::defineBooleanOutputs( const fmippString outputs[], const fmippSize nOutputs )
 {
 	if ( 0 != booleanOutputRefs_ ) delete booleanOutputRefs_;
 
 	nBooleanOutputs_ = nOutputs;
 	booleanOutputRefs_ = new fmiValueReference[nOutputs];
-	for ( size_t i = 0; i < nOutputs; ++i ) {
+	for ( fmippSize i = 0; i < nOutputs; ++i ) {
 		booleanOutputRefs_[i] = fmu_->getValueRef( outputs[i] );
 
-		if ( fmiTrue == loggingOn_ )
+		if ( fmippTrue == loggingOn_ )
 		{
 			stringstream msg;
 			msg << "add " << outputs[i] << " (" << booleanOutputRefs_[i] << ") "
@@ -209,98 +198,91 @@ void InterpolatingFixedStepSizeFMU::defineBooleanOutputs( const string outputs[]
 	}
 }
 
-
-void InterpolatingFixedStepSizeFMU::defineStringOutputs( const string outputs[], const size_t nOutputs )
+void InterpolatingFixedStepSizeFMU::defineStringOutputs( const fmippString outputs[], const fmippSize nOutputs )
 {
 	if ( 0 != stringOutputRefs_ ) delete stringOutputRefs_;
 
 	nStringOutputs_ = nOutputs;
 	stringOutputRefs_ = new fmiValueReference[nOutputs];
-	for ( size_t i = 0; i < nOutputs; ++i ) {
+	for ( fmippSize i = 0; i < nOutputs; ++i ) {
 		stringOutputRefs_[i] = fmu_->getValueRef( outputs[i] );
 
-		if ( fmiTrue == loggingOn_ )
+		if ( fmippTrue == loggingOn_ )
 		{
 			stringstream msg;
 			msg << "add " << outputs[i] << " (" << stringOutputRefs_[i] << ") "
-			    << "to string output variables";
+			    << "to fmippString output variables";
 			fmu_->sendDebugMessage( msg.str() );
 		}
 	}
 }
 
-
-void InterpolatingFixedStepSizeFMU::setInitialInputs( const std::string realVariableNames[],
-					 const fmiReal* realValues,
-					 std::size_t nRealVars,
-					 const std::string integerVariableNames[],
-					 const fmiInteger* integerValues,
-					 std::size_t nIntegerVars,
-					 const std::string booleanVariableNames[],
-					 const fmiBoolean* booleanValues,
-					 std::size_t nBooleanVars,
-					 const std::string stringVariableNames[],
-					 const std::string* stringValues,
-					 std::size_t nStringVars )
+void InterpolatingFixedStepSizeFMU::setInitialInputs( const fmippString realVariableNames[],
+					 const fmippReal* realValues,
+					 fmippSize nRealVars,
+					 const fmippString integerVariableNames[],
+					 const fmippInteger* integerValues,
+					 fmippSize nIntegerVars,
+					 const fmippString booleanVariableNames[],
+					 const fmippBoolean* booleanValues,
+					 fmippSize nBooleanVars,
+					 const fmippString stringVariableNames[],
+					 const fmippString* stringValues,
+					 fmippSize nStringVars )
 {
-	for ( size_t i = 0; i < nRealVars; ++i ) {
+	for ( fmippSize i = 0; i < nRealVars; ++i ) {
 		fmu_->setValue(realVariableNames[i], realValues[i]);
 	}
-	for ( size_t i = 0; i < nIntegerVars; ++i ) {
+	for ( fmippSize i = 0; i < nIntegerVars; ++i ) {
 		fmu_->setValue(integerVariableNames[i], integerValues[i]);
 	}
-	for ( size_t i = 0; i < nBooleanVars; ++i ) {
+	for ( fmippSize i = 0; i < nBooleanVars; ++i ) {
 		fmu_->setValue(booleanVariableNames[i], booleanValues[i]);
 	}
-	for ( size_t i = 0; i < nStringVars; ++i ) {
+	for ( fmippSize i = 0; i < nStringVars; ++i ) {
 		fmu_->setValue(stringVariableNames[i], stringValues[i]);
 	}
 }
 
-
-void InterpolatingFixedStepSizeFMU::getOutputs( fmiReal* outputs ) const
+void InterpolatingFixedStepSizeFMU::getOutputs( fmippReal* outputs ) const
 {
-	for ( size_t i = 0; i < nRealOutputs_; ++i ) {
+	for ( fmippSize i = 0; i < nRealOutputs_; ++i ) {
 		fmu_->getValue( realOutputRefs_[i], outputs[i] );
 	}
 }
 
-
-void InterpolatingFixedStepSizeFMU::getOutputs( fmiInteger* outputs ) const
+void InterpolatingFixedStepSizeFMU::getOutputs( fmippInteger* outputs ) const
 {
-	for ( size_t i = 0; i < nIntegerOutputs_; ++i ) {
+	for ( fmippSize i = 0; i < nIntegerOutputs_; ++i ) {
 		fmu_->getValue( integerOutputRefs_[i], outputs[i] );
 	}
 }
 
-
-void InterpolatingFixedStepSizeFMU::getOutputs( fmiBoolean* outputs ) const
+void InterpolatingFixedStepSizeFMU::getOutputs( fmippBoolean* outputs ) const
 {
-	for ( size_t i = 0; i < nBooleanOutputs_; ++i ) {
+	for ( fmippSize i = 0; i < nBooleanOutputs_; ++i ) {
 		fmu_->getValue( booleanOutputRefs_[i], outputs[i] );
 	}
 }
 
-
-void InterpolatingFixedStepSizeFMU::getOutputs( std::string* outputs ) const
+void InterpolatingFixedStepSizeFMU::getOutputs( fmippString* outputs ) const
 {
-	for ( size_t i = 0; i < nStringOutputs_; ++i ) {
+	for ( fmippSize i = 0; i < nStringOutputs_; ++i ) {
 		fmu_->getValue( stringOutputRefs_[i], outputs[i] );
 	}
 }
 
-
-int InterpolatingFixedStepSizeFMU::init( const std::string& instanceName,
-			    const std::string realVariableNames[],
-			    const fmiReal* realValues,
-			    const std::size_t nRealVars,
-			    const fmiTime startTime,
-			    const fmiTime communicationStepSize,
-			    const fmiBoolean stopTimeDefined,
-			    const fmiTime stopTime,
-			    const fmiReal timeout,
-			    const fmiBoolean visible,
-			    const fmiBoolean interactive )
+int InterpolatingFixedStepSizeFMU::init( const fmippString& instanceName,
+			    const fmippString realVariableNames[],
+			    const fmippReal* realValues,
+			    const fmippSize nRealVars,
+			    const fmippTime startTime,
+			    const fmippTime communicationStepSize,
+			    const fmippBoolean stopTimeDefined,
+			    const fmippTime stopTime,
+			    const fmippReal timeout,
+			    const fmippBoolean visible,
+			    const fmippBoolean interactive )
 {
 	return init( instanceName,
 	      realVariableNames, realValues, nRealVars,
@@ -312,34 +294,33 @@ int InterpolatingFixedStepSizeFMU::init( const std::string& instanceName,
 	      timeout, visible, interactive );
 }
 
-
-int InterpolatingFixedStepSizeFMU::init( const std::string& instanceName,
-			    const std::string realVariableNames[],
-			    const fmiReal* realValues,
-			    const std::size_t nRealVars,
-			    const std::string integerVariableNames[],
-			    const fmiInteger* integerValues,
-			    const std::size_t nIntegerVars,
-			    const std::string booleanVariableNames[],
-			    const fmiBoolean* booleanValues,
-			    const std::size_t nBooleanVars,
-			    const std::string stringVariableNames[],
-			    const std::string* stringValues,
-			    const std::size_t nStringVars,
-			    const fmiTime startTime,
-			    const fmiTime communicationStepSize,
-			    const fmiBoolean stopTimeDefined,
-			    const fmiTime stopTime,
-			    const fmiReal timeout,
-			    const fmiBoolean visible,
-			    const fmiBoolean interactive )
+int InterpolatingFixedStepSizeFMU::init( const fmippString& instanceName,
+			    const fmippString realVariableNames[],
+			    const fmippReal* realValues,
+			    const fmippSize nRealVars,
+			    const fmippString integerVariableNames[],
+			    const fmippInteger* integerValues,
+			    const fmippSize nIntegerVars,
+			    const fmippString booleanVariableNames[],
+			    const fmippBoolean* booleanValues,
+			    const fmippSize nBooleanVars,
+			    const fmippString stringVariableNames[],
+			    const fmippString* stringValues,
+			    const fmippSize nStringVars,
+			    const fmippTime startTime,
+			    const fmippTime communicationStepSize,
+			    const fmippBoolean stopTimeDefined,
+			    const fmippTime stopTime,
+			    const fmippReal timeout,
+			    const fmippBoolean visible,
+			    const fmippBoolean interactive )
 {
 	assert( timeout >= 0. );
 	assert( communicationStepSize > 0. );
 
-	fmiStatus status = fmu_->instantiate( instanceName, timeout, visible, interactive );
+	fmippStatus status = fmu_->instantiate( instanceName, timeout, visible, interactive );
 
-	if ( status != fmiOK ) return 0;
+	if ( status != fmippOK ) return 0;
 
 	// Set inputs.
 	setInitialInputs( realVariableNames, realValues, nRealVars,
@@ -348,7 +329,7 @@ int InterpolatingFixedStepSizeFMU::init( const std::string& instanceName,
 			  stringVariableNames, stringValues, nStringVars );
 
 	// Intialize FMU.
-	if ( fmu_->initialize( startTime, stopTimeDefined, stopTime ) != fmiOK ) return 0;
+	if ( fmu_->initialize( startTime, stopTimeDefined, stopTime ) != fmippOK ) return 0;
 
 	HistoryEntry initState( startTime, 0, nRealOutputs_, nIntegerOutputs_, nBooleanOutputs_, nStringOutputs_ );
 
@@ -363,38 +344,35 @@ int InterpolatingFixedStepSizeFMU::init( const std::string& instanceName,
 
 	currentCommunicationPoint_ = startTime;
 	communicationStepSize_ = communicationStepSize;
-	finalCommunicationPoint_ = ( stopTimeDefined == fmiTrue ) ? stopTime : INVALID_FMI_TIME;
+	finalCommunicationPoint_ = ( stopTimeDefined == fmippTrue ) ? stopTime : INVALID_FMI_TIME;
 
 	return 1;  /* return 1 on success, 0 on failure */
 }
 
-
 /** Interpolate FMU state between two steps. **/
-void InterpolatingFixedStepSizeFMU::interpolateCurrentState( fmiTime t )
+void InterpolatingFixedStepSizeFMU::interpolateCurrentState( fmippTime t )
 {
 	if ( t == nextState_.time_ ) {
 		currentState_ = nextState_;
 		return;
 	}
 
-	for ( size_t i = 0; i < nRealOutputs_; ++i ) {
+	for ( fmippSize i = 0; i < nRealOutputs_; ++i ) {
 		currentState_.realValues_[i] = interpolateValue( t, previousState_.time_, previousState_.realValues_[i], nextState_.time_, nextState_.realValues_[i] );
 	}
 
 	currentState_.time_ = t;
 }
 
-
 /* Linear value interpolation. */
-fmiReal InterpolatingFixedStepSizeFMU::interpolateValue( fmiReal x, fmiReal x0, fmiReal y0, fmiReal x1, fmiReal y1 ) const
+fmippReal InterpolatingFixedStepSizeFMU::interpolateValue( fmippReal x, fmippReal x0, fmippReal y0, fmippReal x1, fmippReal y1 ) const
 {
 	return y0 + (x - x0)*(y1 - y0)/(x1 - x0);
 }
 
-
-fmiTime InterpolatingFixedStepSizeFMU::sync( fmiTime t0, fmiTime t1 )
+fmippTime InterpolatingFixedStepSizeFMU::sync( fmippTime t0, fmippTime t1 )
 {
-	if ( fmiTrue == loggingOn_ )
+	if ( fmippTrue == loggingOn_ )
 	{
 		stringstream msg;
 		msg << "syncing FMU - t0 = " << t0 << ", t1 = " << t1;
@@ -408,13 +386,13 @@ fmiTime InterpolatingFixedStepSizeFMU::sync( fmiTime t0, fmiTime t1 )
 		{
 			previousState_ = nextState_;
 
-			fmiStatus status = fmu_->doStep( currentCommunicationPoint_, communicationStepSize_, fmiTrue );
+			fmippStatus status = fmu_->doStep( currentCommunicationPoint_, communicationStepSize_, fmippTrue );
 
-			if ( fmiOK != status ) {
+			if ( fmippOK != status ) {
 				stringstream message;
 				message << "doStep( " << currentCommunicationPoint_ 
 					<< ", " << communicationStepSize_
-					<< ", fmiTrue ) failed - status = " << status << std::endl;
+					<< ", fmippTrue ) failed - status = " << status << endl;
 				fmu_->sendDebugMessage( message.str() );
 				return currentCommunicationPoint_;
 			}
@@ -432,23 +410,22 @@ fmiTime InterpolatingFixedStepSizeFMU::sync( fmiTime t0, fmiTime t1 )
 
 	interpolateCurrentState( t1 );
 
-	fmiTime nextSyncTime = ( t1 < currentCommunicationPoint_ ) ?
+	fmippTime nextSyncTime = ( t1 < currentCommunicationPoint_ ) ?
 		currentCommunicationPoint_ : 
 		currentCommunicationPoint_ + communicationStepSize_;
 
 	return nextSyncTime;
 }
 
-
 /* Note that the inputs are set at the _end_ of the interval [t0, t1]. */
-fmiTime InterpolatingFixedStepSizeFMU::sync( fmiTime t0, fmiTime t1,
-	fmiReal* realInputs, fmiInteger* integerInputs,
-	fmiBoolean* booleanInputs, std::string* stringInputs,
-	fmiBoolean iterateOnce )
+fmippTime InterpolatingFixedStepSizeFMU::sync( fmippTime t0, fmippTime t1,
+	fmippReal* realInputs, fmippInteger* integerInputs,
+	fmippBoolean* booleanInputs, fmippString* stringInputs,
+	fmippBoolean iterateOnce )
 {
-	fmiTime returnTime = sync( t0, t1 );
+	fmippTime returnTime = sync( t0, t1 );
 
-	if ( fmiTrue == loggingOn_ ) fmu_->sendDebugMessage( "syncing FMU with inputs" );
+	if ( fmippTrue == loggingOn_ ) fmu_->sendDebugMessage( "syncing FMU with inputs" );
 
 	// Set the new inputs.
 	// \FIXME Should this function issue a warning/exception in case an input is a null pointer but the number of defined inputs is not zero? Or should it be quietly tolerated that there are sometimes no inputs?
@@ -457,22 +434,21 @@ fmiTime InterpolatingFixedStepSizeFMU::sync( fmiTime t0, fmiTime t1,
 	if ( 0 != booleanInputs ) setInputs( booleanInputs );
 	if ( 0 != stringInputs ) setInputs( stringInputs );
 
-	if ( ( fmiTrue == iterateOnce ) && 
+	if ( ( fmippTrue == iterateOnce ) && 
 	     ( t1 == currentCommunicationPoint_ ) ) this->iterateOnce();
 
 	 return returnTime;
 }
 
-
 void
 InterpolatingFixedStepSizeFMU::iterateOnce()
 {
-	fmiStatus status = fmu_->doStep( currentCommunicationPoint_, 0., fmiTrue );
+	fmippStatus status = fmu_->doStep( currentCommunicationPoint_, 0., fmippTrue );
 
-	if ( fmiOK != status ) {
+	if ( fmippOK != status ) {
 		stringstream message;
 		message << "doStep( " << currentCommunicationPoint_
-			<< ", 0., fmiTrue ) failed - status = " << status << std::endl;
+			<< ", 0., fmippTrue ) failed - status = " << status << endl;
 		fmu_->sendDebugMessage( message.str().c_str() );
 	}
 
@@ -483,23 +459,21 @@ InterpolatingFixedStepSizeFMU::iterateOnce()
 	getOutputs( currentState_.stringValues_ );
 }
 
-
-fmiStatus
+fmippStatus
 InterpolatingFixedStepSizeFMU::getLastStatus() const
 {
-	if ( 0 == fmu_ ) return fmiFatal;
+	if ( 0 == fmu_ ) return fmippFatal;
 	return fmu_->getLastStatus();
 }
 
+fmippStatus InterpolatingFixedStepSizeFMU::setInputs(fmippReal* inputs) const {
 
-fmiStatus InterpolatingFixedStepSizeFMU::setInputs(fmiReal* inputs) const {
+	fmippStatus status = fmippOK;
 
-	fmiStatus status = fmiOK;
+	for ( fmippSize i = 0; i < nRealInputs_; ++i ) {
+		if ( fmippOK != fmu_->setValue( realInputRefs_[i], inputs[i]) ) status = fmippError;
 
-	for ( size_t i = 0; i < nRealInputs_; ++i ) {
-		if ( fmiOK != fmu_->setValue( realInputRefs_[i], inputs[i]) ) status = fmiError;
-
-		if ( fmiTrue == loggingOn_ )
+		if ( fmippTrue == loggingOn_ )
 		{
 			stringstream msg;
 			msg << "set real input " << realInputRefs_[i] << " = " << inputs[i];
@@ -510,15 +484,14 @@ fmiStatus InterpolatingFixedStepSizeFMU::setInputs(fmiReal* inputs) const {
 	return status;
 }
 
+fmippStatus InterpolatingFixedStepSizeFMU::setInputs(fmippInteger* inputs) const {
 
-fmiStatus InterpolatingFixedStepSizeFMU::setInputs(fmiInteger* inputs) const {
+	fmippStatus status = fmippOK;
 
-	fmiStatus status = fmiOK;
+	for ( fmippSize i = 0; i < nIntegerInputs_; ++i ) {
+		if ( fmippOK != fmu_->setValue( integerInputRefs_[i], inputs[i]) ) status = fmippError;
 
-	for ( size_t i = 0; i < nIntegerInputs_; ++i ) {
-		if ( fmiOK != fmu_->setValue( integerInputRefs_[i], inputs[i]) ) status = fmiError;
-
-		if ( fmiTrue == loggingOn_ )
+		if ( fmippTrue == loggingOn_ )
 		{
 			stringstream msg;
 			msg << "set integer input " << integerInputRefs_[i] << " = " << inputs[i];
@@ -529,15 +502,14 @@ fmiStatus InterpolatingFixedStepSizeFMU::setInputs(fmiInteger* inputs) const {
 	return status;
 }
 
+fmippStatus InterpolatingFixedStepSizeFMU::setInputs(fmippBoolean* inputs) const {
 
-fmiStatus InterpolatingFixedStepSizeFMU::setInputs(fmiBoolean* inputs) const {
+	fmippStatus status = fmippOK;
 
-	fmiStatus status = fmiOK;
+	for ( fmippSize i = 0; i < nBooleanInputs_; ++i ) {
+		if ( fmippOK != fmu_->setValue( booleanInputRefs_[i], inputs[i]) ) status = fmippError;
 
-	for ( size_t i = 0; i < nBooleanInputs_; ++i ) {
-		if ( fmiOK != fmu_->setValue( booleanInputRefs_[i], inputs[i]) ) status = fmiError;
-
-		if ( fmiTrue == loggingOn_ )
+		if ( fmippTrue == loggingOn_ )
 		{
 			stringstream msg;
 			msg << "set boolean input " << booleanInputRefs_[i] << " = " << inputs[i];
@@ -548,18 +520,17 @@ fmiStatus InterpolatingFixedStepSizeFMU::setInputs(fmiBoolean* inputs) const {
 	return status;
 }
 
+fmippStatus InterpolatingFixedStepSizeFMU::setInputs(fmippString* inputs) const {
 
-fmiStatus InterpolatingFixedStepSizeFMU::setInputs(std::string* inputs) const {
+	fmippStatus status = fmippOK;
 
-	fmiStatus status = fmiOK;
+	for ( fmippSize i = 0; i < nStringInputs_; ++i ) {
+		if ( fmippOK != fmu_->setValue( stringInputRefs_[i], inputs[i]) ) status = fmippError;
 
-	for ( size_t i = 0; i < nStringInputs_; ++i ) {
-		if ( fmiOK != fmu_->setValue( stringInputRefs_[i], inputs[i]) ) status = fmiError;
-
-		if ( fmiTrue == loggingOn_ )
+		if ( fmippTrue == loggingOn_ )
 		{
 			stringstream msg;
-			msg << "set string input " << stringInputRefs_[i] << " = " << inputs[i];
+			msg << "set fmippString input " << stringInputRefs_[i] << " = " << inputs[i];
 			fmu_->sendDebugMessage( msg.str() );
 		}
 	}
